@@ -10,9 +10,7 @@ use List::Util qw(sum max);
 
 use Text::Aligner qw(align);
 
-BEGIN {
-    our $VERSION = '1.131';
-}
+our $VERSION = '1.133';
 
 use overload (
     # Don't stringify when only doing boolean tests, since stringification can
@@ -886,13 +884,18 @@ use Carp;
     }
 }
 
-__END__
-########################################### main pod documentation begin ##
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Text::Table - Organize Data in Tables
 
+=head1 VERSION
+
+version 1.133
+
 =head1 SYNOPSIS
 
     use Text::Table;
@@ -959,7 +962,7 @@ the length of the longest partial line.  The largest number of title
 lines in a column determines how many title lines the table has as a
 whole, including the case that no column has any titles.
 
-On output, Columns are separated by a single blank.  You can control
+On output, columns are separated by a single blank.  You can control
 what goes between columns by specifying separators between (or before,
 or after) columns.  Separators don't contain any data and don't count
 in column indexing.  They also don't accumulate: in a sequence of only
@@ -1110,7 +1113,7 @@ The hash representation of a separator has the format
     }
 
 $title is the separator to be used in the title area and $body
-the one for the body.  If only one is given, the other is used for
+the one for the body.  If only one is given, it will be used for
 both.  If none is given, a blank is used.  If one is shorter than
 the other, it is blank filled on the right.
 
@@ -1395,7 +1398,7 @@ one character is specified (the second call), it replaces the blanks
 in the first form, but non-blank column separators are retained.  If
 a second character is specified, it replaces the non-blank parts of
 the separators.  So specifying the same character twice gives a solid
-line of table width.  Another useful combo is C<$tb-E<lt>rule( '-', '+')>,
+line of table width.  Another useful combo is C<$tb-E<gt>rule( '-', '+')>,
 together with separators that contain a single nonblank "|", for a
 popular representation of line crossings.
 
@@ -1480,6 +1483,147 @@ LICENSE file included with this module.
 
 L<Text::Aligner>, L<perl(1)> .
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2002 by Anno Siegel and others.
+
+This is free software, licensed under:
+
+  The ISC License
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Text-Table> or by email to
+L<bug-text-table@rt.cpan.org|mailto:bug-text-table@rt.cpan.org>.
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Text::Table
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/Text-Table>
+
+=item *
+
+Search CPAN
+
+The default CPAN search engine, useful to view POD in HTML format.
+
+L<http://search.cpan.org/dist/Text-Table>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Text-Table>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
+
+L<http://annocpan.org/dist/Text-Table>
+
+=item *
+
+CPAN Ratings
+
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
+L<http://cpanratings.perl.org/d/Text-Table>
+
+=item *
+
+CPAN Forum
+
+The CPAN Forum is a web forum for discussing Perl modules.
+
+L<http://cpanforum.com/dist/Text-Table>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Text-Table>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/T/Text-Table>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Text-Table>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Text::Table>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-text-table at rt.cpan.org>, or through
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Text-Table>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://github.com/shlomif/Text-Table>
+
+  git clone ssh://git@github.com:shlomif/Text-Table.git
+
 =cut
 
+__END__
+########################################### main pod documentation begin ##
+
+
 1;
